@@ -130,7 +130,7 @@ sieve_tool_init(const char *name, int *argc, char **argv[],
 	pool_t pool;
 
 	if (no_config)
-		service_flags |= MASTER_SERVICE_FLAG_NO_CONFIG_SETTINGS;
+		service_flags |= MASTER_SERVICE_FLAG_CONFIG_DEFAULTS;
 
 	getopt_str = t_strconcat(getopt_str, "DP:x:", NULL);
 	master_service = master_service_init(name, service_flags,
@@ -587,7 +587,7 @@ sieve_tool_script_parse_location(struct sieve_tool *tool, const char *location,
 		settings_instance_find(svinst->event);
 	const char *prefix = t_strdup_printf("sieve_script/%s", storage_name);
 
-	settings_override(set_instance, "sieve_script", storage_name,
+	settings_override(set_instance, "sieve_script+", storage_name,
 			  SETTINGS_OVERRIDE_TYPE_2ND_CLI_PARAM);
 	settings_override(set_instance,
 			  t_strdup_printf("%s/sieve_script_storage", prefix),
