@@ -166,8 +166,8 @@ sieve_script_create_common(struct sieve_instance *svinst,
 		sieve_storage_unref(&storage);
 		if (ret > 0 && open &&
 		    sieve_script_open(script, error_code_r) < 0) {
-			*error_r = sieve_storage_get_last_error(
-				storage, error_code_r);
+			*error_r = sieve_script_get_last_error(
+				script, error_code_r);
 			sieve_script_unref(&script);
 			if (*error_code_r == SIEVE_ERROR_NOT_FOUND)
 				continue;
@@ -1232,7 +1232,7 @@ int sieve_script_sequence_next(struct sieve_script_sequence *sseq,
 			i_assert(storage->error_code != SIEVE_ERROR_NONE);
 			i_assert(storage->error != NULL);
 
-			if (*error_code_r == SIEVE_ERROR_NOT_FOUND)
+			if (storage->error_code == SIEVE_ERROR_NOT_FOUND)
 				ret = 0;
 			else {
 				*error_code_r = storage->error_code;
