@@ -760,13 +760,12 @@ static int edit_mail_headers_parse(struct edit_mail *edmail)
 			struct _header_field_index *field_idx_new;
 			struct _header_field *field;
 
+			i_assert(hdr != NULL);
 			if (hdr->eoh) {
 				/* Record whether header ends in CRLF or LF */
 				edmail->eoh_crlf = hdr->crlf_newline;
-			}
-
-			if (hdr == NULL || hdr->eoh)
 				break;
+			}
 
 			/* Skip bad headers */
 			if (hdr->name_len == 0)
@@ -2087,8 +2086,14 @@ static ssize_t edit_mail_istream_read(struct istream_private *stream)
 		copy_v_offset = edmail->hdr_size.physical_size;
 	}
 
-	return merge_from_parent(edstream, parent_v_offset, (uoff_t)-1,
-				 copy_v_offset);
+	ret = merge_from_parent(edstream, parent_v_offset, (uoff_t)-1,
+				copy_v_offset);
+	if (ret != 0)
+		return ret;
+
+	stream->istream.eof = stream->parent->eof;
+	edstream->eof = stream->parent->eof;
+	return -1;
 }
 
 static void
