@@ -226,11 +226,6 @@ static int
 proxy_write_auth_response(struct managesieve_client *client,
 			  const char *challenge, string_t *str)
 {
-	const unsigned char *data;
-	size_t data_len;
-	const char *error;
-	int ret;
-
 	if (base64_decode(challenge, strlen(challenge), str) < 0) {
 		login_proxy_failed(client->common.login_proxy,
 			login_proxy_get_event(client->common.login_proxy),
@@ -238,25 +233,12 @@ proxy_write_auth_response(struct managesieve_client *client,
 			"Server sent invalid base64 data in AUTHENTICATE response");
 		return -1;
 	}
-	ret = dsasl_client_input(client->common.proxy_sasl_client,
-				 str_data(str), str_len(str), &error);
-	if (ret == 0) {
-		ret = dsasl_client_output(client->common.proxy_sasl_client,
-					  &data, &data_len, &error);
-	}
-	if (ret < 0) {
-		const char *reason = t_strdup_printf(
-			"Server sent invalid authentication data: %s", error);
-		login_proxy_failed(client->common.login_proxy,
-			login_proxy_get_event(client->common.login_proxy),
-			LOGIN_PROXY_FAILURE_TYPE_PROTOCOL, reason);
+	if (login_proxy_sasl_step(&client->common, str) < 0)
 		return -1;
-	}
-	i_assert(ret == 0);
-
-	str_truncate(str, 0);
-	proxy_write_auth_data(data, data_len, str);
-	str_append(str, "\r\n");
+	/* str is guaranteed to contain only base64 characters, which don't
+	   need escaping. Add the beginning and end quotes. */
+	str_insert(str, 0, "\"");
+	str_append_c(str, '"');
 	return 0;
 }
 
@@ -658,7 +640,7 @@ int managesieve_proxy_parse_line(struct client *client, const char *line)
 						       &reason))
 			failure_type = LOGIN_PROXY_FAILURE_TYPE_AUTH_REDIRECT;
 		else {
-			failure_type = LOGIN_PROXY_FAILURE_TYPE_AUTH;
+			failure_type = LOGIN_PROXY_FAILURE_TYPE_AUTH_REPLIED;
 			client_send_no(client, AUTH_FAILED_MSG);
 		}
 
@@ -672,7 +654,6 @@ int managesieve_proxy_parse_line(struct client *client, const char *line)
 	}
 
 	i_unreached();
-	return -1;
 }
 
 void managesieve_proxy_reset(struct client *client)
@@ -702,6 +683,7 @@ managesieve_proxy_send_failure_reply(struct client *client,
 		break;
 	case LOGIN_PROXY_FAILURE_TYPE_INTERNAL_CONFIG:
 	case LOGIN_PROXY_FAILURE_TYPE_REMOTE_CONFIG:
+	case LOGIN_PROXY_FAILURE_TYPE_AUTH_NOT_REPLIED:
 		client_send_reply_code(client, MANAGESIEVE_CMD_REPLY_NO,
 				       NULL, LOGIN_PROXY_FAILURE_MSG);
 		break;
@@ -709,7 +691,7 @@ managesieve_proxy_send_failure_reply(struct client *client,
 		client_send_reply_code(client, MANAGESIEVE_CMD_REPLY_NO,
 				       "TRYLATER", reason);
 		break;
-	case LOGIN_PROXY_FAILURE_TYPE_AUTH:
+	case LOGIN_PROXY_FAILURE_TYPE_AUTH_REPLIED:
 		/* reply was already sent */
 		break;
 	}
